@@ -5,9 +5,8 @@ SLIM vectorizer, using SLIM as a feature extraction scheme
 import numpy as np
 import pandas as pd
 
-from ..base import TransformerMixin
-from ..itemsets import SLIM
-from ..itemsets.slim import _to_vertical, cover
+from skmine.itemsets import SLIM
+from skmine.itemsets.slim import _to_vertical, cover
 
 STRATEGIES = ("codes", "one-hot")
 
@@ -17,7 +16,7 @@ def _filter_stop_items(D, stop_items):
         yield set(t).difference(stop_items)
 
 
-class SLIMVectorizer(SLIM, TransformerMixin):
+class SLIMVectorizer(SLIM):
     """SLIM mining, turned into a feature extraction step for sklearn
 
     `k` new itemsets (associations of one or more items) are learned at training time
@@ -51,7 +50,8 @@ class SLIMVectorizer(SLIM, TransformerMixin):
     --------
     >>> from skmine.feature_extraction import SLIMVectorizer
     >>> D = [['bananas', 'milk'], ['milk', 'bananas', 'cookies'], ['cookies', 'butter', 'tea']]
-    >>> SLIMVectorizer(k=2).fit_transform(D)
+    >>> res  = SLIMVectorizer(k=2).fit_transform(D)
+    >>> print(res.to_string())
        (bananas, milk)  (cookies,)
     0              0.4         0.0
     1              0.4         0.4
@@ -70,7 +70,7 @@ class SLIMVectorizer(SLIM, TransformerMixin):
     patterns should output matrices with very few zeros.
     """
 
-    def __init__(self, strategy="codes", *, k=5, pruning=False, stop_items=None, **kwargs):
+    def __init__(self, strategy="codes", k=5, pruning=False, stop_items=None, **kwargs):
         super().__init__(**kwargs)
         self.k = k
         self.pruning = pruning
@@ -84,7 +84,7 @@ class SLIMVectorizer(SLIM, TransformerMixin):
             D = _filter_stop_items(D, stop_items=self.stop_items)
         return super().fit(D)
 
-    def transform(self, D, y=None):
+    def transform(self, newD, y=None, **tsf_params) -> pd.DataFrame:
         """Transform new data
 
         Parameters
@@ -102,9 +102,8 @@ class SLIMVectorizer(SLIM, TransformerMixin):
         skmine.itemsets.SLIM.cover
         """
         stop_items = self.stop_items or set()
-        D_sct, _len = _to_vertical(D, stop_items=stop_items, return_len=True)
-
-        code_lengths = self.discover(return_tids=False, singletons=True, drop_null_usage=False)
+        D_sct, _len = _to_vertical(newD, stop_items=stop_items, return_len=True)
+        code_lengths = super().transform(newD, return_tids=False, singletons=True, drop_null_usage=False)
         code_lengths = pd.Series(code_lengths["usage"].values, index=code_lengths["itemset"].apply(tuple))
         code_lengths = code_lengths[code_lengths.index.map(set(D_sct).issuperset)]
 
