@@ -9,21 +9,19 @@ and https://eda.rg.cispa.io/pres/ida14-slimmer-poster.pdf
 #          Cyril Regan <cyril.regan@loria.fr>
 # License: BSD 3 clause
 
+import time
 from collections import Counter, defaultdict
 from functools import lru_cache, reduce
 from itertools import chain
 
 import numpy as np
 import pandas as pd
-import time
-
-from sortedcontainers import SortedDict
 from pyroaring import BitMap as Bitmap
-
+from sklearn.base import BaseEstimator
 from sklearn.utils.validation import check_is_fitted
-from sklearn.base import BaseEstimator, TransformerMixin
-from sklearn.preprocessing import MultiLabelBinarizer
+from sortedcontainers import SortedDict
 
+from skmine.base import TransformerMixin
 from ..utils import _check_D, supervised_to_unsupervised
 
 
@@ -118,7 +116,7 @@ class SLIM(BaseEstimator, TransformerMixin):
     --------
     >>> from skmine.itemsets import SLIM
     >>> D = [['bananas', 'milk'], ['milk', 'bananas', 'cookies'], ['cookies', 'butter', 'tea']]
-    >>> SLIM().fit(D).transform(singletons=True, return_tids=True)
+    >>> SLIM().fit(D).transform(D, singletons=True, return_tids=True)
                itemset    tids
     0  [bananas, milk]  (0, 1)
     1    [butter, tea]     (2)
@@ -139,31 +137,14 @@ class SLIM(BaseEstimator, TransformerMixin):
         self.max_time = max_time
         self.items = items
 
-    def _more_tags(self):  # tags for sklearn check_estimators)
+    def _more_tags(self):
         return {
-            "non_deterministic": True,  # default
-            # "X_types": ['2darray'],  # ["categorical"],  # default
+            "non_deterministic": True,
             "no_validation": True,
             "preserves_dtype": False,
-            # "pairwise": True,
         }
 
-    def fit_transform(self, X, y=None, **tsf_params):  # TODO refactor to TransformerMixin Custom ? for LCM, SLIM
-        """   Override sklearn transformer method to apply optional parameters `tsf_params` on transform  and not to fit
-        Returns a transformed version of `X`: i.e. the fitted codetable
-
-        Returns
-        -------
-        df_new : pandas.Dataframe
-            Codetable fitted from X data.
-        """
-
-        if y is None:
-            return self.fit(X).transform(X, tsf_params)
-        else:
-            return self.fit(X, y).transform(X, tsf_params)
-
-    def fit(self, X, y=None):  # -> self
+    def fit(self, X, y=None):
         """fit SLIM on a transactional dataset
 
         This generates new candidate patterns and add those which improve compression,
@@ -185,7 +166,7 @@ class SLIM(BaseEstimator, TransformerMixin):
         self._validate_data(X, force_all_finite=False, accept_sparse=False, ensure_2d=False,
                             ensure_min_samples=1, dtype=list)
         self.n_features_in_ = X.shape[-1] if not isinstance(X, list) else len(X[-1])
-        # TODO : significant for one-hot D ,not for list of itemset
+        # TODO : significant for one-hot D, not for list of itemset
         start = time.time()
         self.prefit(X, y=y)
         while True:
@@ -239,7 +220,7 @@ class SLIM(BaseEstimator, TransformerMixin):
         >>> new_D = to_tabular([['cookies', 'butter']])
         >>> slim = SLIM().fit(to_tabular(D))
         >>> slim.get_code_length(new_D)
-        0   5.584963
+        0    5.584963
         dtype: float32
 
         See Also
@@ -463,7 +444,6 @@ class SLIM(BaseEstimator, TransformerMixin):
 
         items never seen are dropped out
 
-
         Examples
         --------
         >>> from skmine.itemsets import SLIM
@@ -494,12 +474,16 @@ class SLIM(BaseEstimator, TransformerMixin):
 
         return pd.DataFrame(mat, columns=list(covers.keys()))
 
-    def transform(self, D, singletons=True, return_tids=False, lexicographic_order=True,
-                  drop_null_usage=True, return_dl=False, out=None):
+    def transform(self, D, singletons=True, return_tids=False, lexicographic_order=True, drop_null_usage=True,
+                  return_dl=False, out=None):
         """Get a user-friendly copy of the codetable
 
         Parameters
         ----------
+        D: iterable of iterables or array-like
+            Transactional dataset, either as an iterable of iterables or encoded as tabular binary data.
+            Does not influence the results. Present for compatibility with scikit-learn.
+
         singletons: bool, default=True
             Either to include itemsets of length 1 in the result
 
@@ -526,7 +510,7 @@ class SLIM(BaseEstimator, TransformerMixin):
         -------
         >>> from skmine.itemsets import SLIM
         >>> D = ["ABC", "AB", "BCD"]
-        >>> SLIM().fit_transform(D, singletons=True, return_tids=True, lexicographic_order=True, drop_null_usage=False)
+        >>> SLIM().fit_transform(D, singletons=True, return_tids=False, lexicographic_order=True, drop_null_usage=True)
           itemset  usage
         0  [A, B]      2
         1  [B, D]      1
@@ -574,8 +558,8 @@ class SLIM(BaseEstimator, TransformerMixin):
             return df
 
     def reconstruct(self) -> pd.Series:
-        """reconstruct the original data from the current `self.codetable_`. This is possible because SLIM is a
-        lossless algorithm .
+        """Reconstruct the original data from the current `self.codetable_`. This is possible because SLIM is a
+        lossless algorithm.
 
         Example
         -------
